from enum import Enum

class SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemGeoLocationType0RadiusType1Unit(str, Enum):
    KILOMETERS = "kilometers"

    def __str__(self) -> str:
        return str(self.value)
