from enum import Enum

class SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0NoneOfType0ItemType3SourceType2Type1(str, Enum):
    CSV = "csv"

    def __str__(self) -> str:
        return str(self.value)
