from enum import Enum

class KitchenSinkCompanyResponse200OutputDataItemRoleCountMatchesType0ItemNumMatchingEmployeesType0Type(str, Enum):
    EXACT = "exact"

    def __str__(self) -> str:
        return str(self.value)
