from enum import IntEnum

class TextToCompanySearchParamsResponse200OutputSearchParamsEmployeeCountV2Type0UpperBoundInclusiveType1(IntEnum):
    VALUE_1 = 1

    def __str__(self) -> str:
        return str(self.value)
