from enum import Enum

class CreateSavedSearchBodySearchParamsType0ProfileSearchParamsJobTitleV3Type0AnyOfType0ItemType0Type(str, Enum):
    PLAIN = "plain"

    def __str__(self) -> str:
        return str(self.value)
