from enum import Enum

class CreateSavedSearchBodySearchParamsType2ProfileSearchParamsJobTitleV2Type0AnyOfType0ItemType0Type(str, Enum):
    TERM = "term"

    def __str__(self) -> str:
        return str(self.value)
