from enum import Enum

class CompanySearchBodySearchParamsJobPostingStatsType0AllOfType0ItemType2Rule(str, Enum):
    SENIORITY = "seniority"

    def __str__(self) -> str:
        return str(self.value)
